@@ -180,7 +180,7 @@ if ($#tree == -1) {
                              'id'      => 'a3',
                              'rid'     => 3
                             },
-              ],
+                           ],
               'id'  => 'a1',
               'rid' => 1
              },
@@ -200,7 +200,7 @@ if ($#tree == -1) {
                                             'rid'     => 7,
                                             'id'      => 'a7'
                                            }
-                             ],
+                                          ],
                              'rid' => 6,
                              'id'  => 'a6'
                             },
@@ -217,7 +217,7 @@ if ($#tree == -1) {
                                             'id'      => 'a9',
                                             'rid'     => 9
                                            }
-                             ],
+                                          ],
                              'id'  => 'a8',
                              'rid' => 8
                             },
@@ -234,7 +234,7 @@ if ($#tree == -1) {
                                             'id'      => 'a11',
                                             'rid'     => 11
                                            }
-                             ],
+                                          ],
                              'id'  => 'a10',
                              'rid' => 10
                             },
@@ -251,7 +251,7 @@ if ($#tree == -1) {
                                             'id'      => 'a13',
                                             'rid'     => 13
                                            }
-                             ],
+                                          ],
                              'id'  => 'a12',
                              'rid' => 12
                             },
@@ -268,7 +268,7 @@ if ($#tree == -1) {
                                             'id'      => 'a15',
                                             'rid'     => 15
                                            }
-                             ],
+                                          ],
                              'id'  => 'a14',
                              'rid' => 14
                             },
@@ -285,7 +285,7 @@ if ($#tree == -1) {
                                             'rid'     => 17,
                                             'id'      => 'a17'
                                            }
-                             ],
+                                          ],
                              'rid' => 16,
                              'id'  => 'a16'
                             },
@@ -302,7 +302,7 @@ if ($#tree == -1) {
                                             'id'      => 'a19',
                                             'rid'     => 'a19'
                                            }
-                             ],
+                                          ],
                              'id'  => 'a18',
                              'rid' => 'a18'
                             },
@@ -319,11 +319,11 @@ if ($#tree == -1) {
                                             'id'      => 'a21',
                                             'rid'     => 21
                                            }
-                             ],
+                                          ],
                              'id'  => 'a20',
                              'rid' => 20
                             }
-              ],
+                           ],
               'id'  => 'a5',
               'rid' => 5
              },
@@ -334,7 +334,7 @@ if ($#tree == -1) {
               'id'      => 'a22',
               'rid'     => 22
              }
-    );
+            );
     saveTree($dump, \@tree);
 }
 my $zoom = div(
@@ -345,7 +345,7 @@ my $zoom = div(
                    -class => "treeviewLink$size"
                   },
                   '16'
-                 )
+                )
                  . '&#160;|&#160;'
                  . a(
                      {
@@ -353,7 +353,7 @@ my $zoom = div(
                       -class => "treeviewLink$size"
                      },
                      '22'
-                 )
+                    )
                  . '&#160;|&#160;'
                  . a(
                      {
@@ -361,7 +361,7 @@ my $zoom = div(
                       -class => "treeviewLink$size"
                      },
                      '32'
-                 )
+                    )
                  . '&#160;|&#160;'
                  . a(
                      {
@@ -369,14 +369,15 @@ my $zoom = div(
                       -class => "treeviewLink$size"
                      },
                      '48'
-                 )
-);
+                    )
+              );
 print(
     header(),
     start_html(
-               -title  => 'Edit',
-               -script => jscript() . preload() . $jspart,
-               -style  => {-code => css().qq|
+        -title  => 'Edit',
+        -script => jscript() . preload() . $jspart,
+        -style  => {
+            -code => css() . qq|
                .moveHereContent{
 		  background-color:rgba(214, 210, 208,0.9);
 		  -webkit-box-shadow:0px 0px 1px rgba(0,0,0,0.4);/*black */
@@ -393,8 +394,8 @@ print(
 		  cursor:pointer;
 		}
                |
-               }
-    ),
+                  }
+              ),
     $zoom
       . br() . '
 <div id="moveHere" style="display:none;" class="moveHereContent" width="100px"></div>
@@ -409,7 +410,7 @@ document.body.onmousedown=function(){return false}
 document.body.style.cursor = "default";
 </script>
 <table align="center" class="mainborder" cellpadding="0"  cellspacing="0" summary="mainLayout" ><tr><td align="left">'
-);
+     );
 
 my $m_nPrid = param('rid');
 $m_nPrid =~ s/^a(.*)/$1/;
@@ -458,8 +459,7 @@ SWITCH: {
 
 print "$m_sContent</td></tr></table>", end_html;
 
-sub saveTreeviewEntry
-{
+sub saveTreeviewEntry {
     &load();
     &saveEntry(\@tree, $m_nPrid);
     &updateTree(\@tree);
@@ -471,12 +471,11 @@ sub saveTreeviewEntry
                           width => '*'
                          },
                          Tr(td(Tree(\@tree)))
-    );
+                        );
     TrOver(0);
 }
 
-sub addTreeviewEntry
-{
+sub addTreeviewEntry {
     &load();
     &addEntry(\@tree, $m_nPrid);
     &updateTree(\@tree);
@@ -488,12 +487,11 @@ sub addTreeviewEntry
                           width => '*'
                          },
                          Tr(td(Tree(\@tree)))
-    );
+                        );
     TrOver(0);
 }
 
-sub editTreeview
-{
+sub editTreeview {
     &load();
     &rid();
     saveTree($dump, \@tree);
@@ -506,19 +504,17 @@ sub editTreeview
                           width => '*'
                          },
                          Tr(td(Tree(\@tree)))
-    );
+                        );
     TrOver(0);
 }
 
-sub editTreeviewEntry
-{
+sub editTreeviewEntry {
     &load();
 
     &editEntry(\@tree, $m_nPrid);
 }
 
-sub deleteTreeviewEntry
-{
+sub deleteTreeviewEntry {
     &load();
     &deleteEntry(\@tree, $m_nPrid);
     &updateTree(\@tree);
@@ -530,12 +526,11 @@ sub deleteTreeviewEntry
                           width => '*'
                          },
                          Tr(td(Tree(\@tree)))
-    );
+                        );
     TrOver(0);
 }
 
-sub upEntry
-{
+sub upEntry {
     &load();
     &sortUp(\@tree, $m_nPrid);
     &updateTree(\@tree);
@@ -547,12 +542,11 @@ sub upEntry
                           width => '*'
                          },
                          Tr(td(Tree(\@tree)))
-    );
+                        );
     TrOver(0);
 }
 
-sub MoveTreeViewEntry
-{
+sub MoveTreeViewEntry {
     &load();
 
     my $f = param('from');
@@ -570,15 +564,14 @@ sub MoveTreeViewEntry
                           width => '*'
                          },
                          Tr(td(Tree(\@tree)))
-    );
+                        );
     TrOver(0);
 }
 
-sub moveEntry
-{
+sub moveEntry {
     my $t    = shift;
     my $find = shift;
-    for (my $i = 0; $i <= @$t; $i++) {
+    for (my $i = 0 ; $i <= @$t ; $i++) {
         next if ref @$t[$i] ne "HASH";
         if (@$t[$i]) {
             if (@$t[$i]->{rid} == $find && defined $tN->{id}) {
@@ -592,12 +585,11 @@ sub moveEntry
     }
 }
 
-sub getEntry
-{
+sub getEntry {
     my $t    = shift;
     my $find = shift;
     my $goto = shift;
-    for (my $i = 0; $i < @$t; $i++) {
+    for (my $i = 0 ; $i < @$t ; $i++) {
         next if ref @$t[$i] ne "HASH";
         if (@$t[$i]->{rid} == $find) {
             $tN->{$_} = @$t[$i]->{$_} foreach keys %{@$t[$i]};
@@ -609,8 +601,7 @@ sub getEntry
     }
 }
 
-sub downEntry
-{
+sub downEntry {
     &load();
     $down = 1;
     &sortUp(\@tree, $m_nPrid);
@@ -622,35 +613,49 @@ sub downEntry
                           width => '*'
                          },
                          Tr(td(Tree(\@tree)))
-    );
+                        );
     TrOver(0);
 }
 
-sub newEntry
-{
+sub newEntry {
     $m_sContent .=
-qq(<b>New Entry</b><form action="$ENV{SCRIPT_NAME}#a$m_nPrid"><br/><table align="center" class="mainborder" cellpadding="2"  cellspacing="2" summary="mainLayolut"><tr><td>Text:</td><td><input type="text" value="" name="text"></td></tr><tr><td>Folder</td><td><input type="checkbox" name="folder" /></td></tr>);
+      qq(<b>New Entry</b><form action="$ENV{SCRIPT_NAME}#a$m_nPrid"><br/><table align="center" class="mainborder" cellpadding="2"  cellspacing="2" summary="mainLayolut"><tr><td>Text:</td><td><input type="text" value="" name="text"></td></tr><tr><td>Folder</td><td><input type="checkbox" name="folder" /></td></tr>);
     my $node = help();
     foreach my $key (sort(keys %{$node})) {
-        $m_sContent .= qq(<tr><td></td><td>$node->{$key}</td></tr><tr><td>$key :</td><td><input type="text" value="" name="$key"/><br/></td></tr>) if ($key ne 'class');
+        $m_sContent .=
+          qq(<tr><td></td><td>$node->{$key}</td></tr><tr><td>$key :</td><td><input type="text" value="" name="$key"/><br/></td></tr>)
+          if ($key ne 'class');
     }
-    $m_sContent .= '<tr><td><input type="hidden" name="action" value="addTreeviewEntry"/><input type="hidden" name="rid" value="a' . $m_nPrid . '"></td><td><input type="submit"/></td></tr></table></form>';
+    $m_sContent .=
+      '<tr><td><input type="hidden" name="action" value="addTreeviewEntry"/><input type="hidden" name="rid" value="a'
+      . $m_nPrid
+      . '"></td><td><input type="submit"/></td></tr></table></form>';
 }
 
-sub addEntry
-{
+sub addEntry {
     my $t    = shift;
     my $find = shift;
-    for (my $i = 0; $i < @$t; $i++) {
+    for (my $i = 0 ; $i < @$t ; $i++) {
         if (@$t[$i]->{rid} == $find) {
             my %params = Vars();
             my $node   = {};
             foreach my $key (sort(keys %params)) {
-                $node->{$key} = $params{$key} if ($params{$key} && $key ne 'action' && $key ne 'folder' && $key ne 'subtree' && $key ne 'class' && $key ne 'dump');
-                $node->{$key} = "$ENV{SCRIPT_NAME}?action=$1" if ($key eq 'href' && $params{$key} =~ /^action:\/\/(.*)$/);
+                $node->{$key} = $params{$key}
+                  if (   $params{$key}
+                      && $key ne 'action'
+                      && $key ne 'folder'
+                      && $key ne 'subtree'
+                      && $key ne 'class'
+                      && $key ne 'dump');
+                $node->{$key} = "$ENV{SCRIPT_NAME}?action=$1"
+                  if ($key eq 'href' && $params{$key} =~ /^action:\/\/(.*)$/);
             }
             if (param('folder')) {
-                $node->{'subtree'} = [{text => 'Empty Folder',}];
+                $node->{'subtree'} = [
+                                      {
+                                       text => 'Empty Folder',
+                                      }
+                                     ];
             }
             splice @$t, $i, 0, $node;
             &rid();
@@ -662,16 +667,22 @@ sub addEntry
     }
 }
 
-sub saveEntry
-{
+sub saveEntry {
     my $t    = shift;
     my $find = shift;
-    for (my $i = 0; $i < @$t; $i++) {
+    for (my $i = 0 ; $i < @$t ; $i++) {
         if (@$t[$i]->{rid} == $find) {
             my %params = Vars();
             foreach my $key (sort keys %params) {
-                @$t[$i]->{$key} = $params{$key} if ($params{$key} && $key ne 'action' && $key ne 'folder' && $key ne 'subtree' && $key ne 'class' && $key ne 'dump');
-                @$t[$i]->{$key} = "$ENV{SCRIPT_NAME}?action=$1" if ($key eq 'href' && $params{$key} =~ /^action:\/\/(.*)$/);
+                @$t[$i]->{$key} = $params{$key}
+                  if (   $params{$key}
+                      && $key ne 'action'
+                      && $key ne 'folder'
+                      && $key ne 'subtree'
+                      && $key ne 'class'
+                      && $key ne 'dump');
+                @$t[$i]->{$key} = "$ENV{SCRIPT_NAME}?action=$1"
+                  if ($key eq 'href' && $params{$key} =~ /^action:\/\/(.*)$/);
             }
             saveTree($dump, \@tree);
             return;
@@ -681,28 +692,41 @@ sub saveEntry
     }
 }
 
-sub editEntry
-{
+sub editEntry {
     my $t    = shift;
     my $find = shift;
     my $href = "$ENV{SCRIPT_NAME}?action=editTreeviewEntry";
-    for (my $i = 0; $i < @$t; $i++) {
+    for (my $i = 0 ; $i < @$t ; $i++) {
         if (@$t[$i]->{rid} == $find) {
             $m_sContent .= br();
-            $m_sContent .= "<b>" . @$t[$i]->{text} . '</b><form action="' . $href . "#a$m_nPrid" . '><table align=" center " class=" mainborder " cellpadding="0"  cellspacing="0" summary="mainLayolut">';
+            $m_sContent .= "<b>"
+              . @$t[$i]->{text}
+              . '</b><form action="'
+              . $href
+              . "#a$m_nPrid"
+              . '><table align=" center " class=" mainborder " cellpadding="0"  cellspacing="0" summary="mainLayolut">';
             language('de') if $ENV{HTTP_ACCEPT_LANGUAGE} =~ /^de.*/;
             my $node = help();
             foreach my $key (sort(keys %{@$t[$i]})) {
-                $m_sContent .= "<tr><td></td><td>$node->{$key}</td></tr>" if (defined $node->{$key});
-                $m_sContent .= qq(<tr><td>$key </td><td><input type="text" value="@$t[$i]->{$key}" name="$key"></td></tr>)
-                  if ($key ne 'subtree' && $key ne 'rid' && $key ne 'action' && $key ne 'dump' && $key ne 'class' && $key ne 'addition');
+                $m_sContent .= "<tr><td></td><td>$node->{$key}</td></tr>"
+                  if (defined $node->{$key});
+                $m_sContent .=
+                  qq(<tr><td>$key </td><td><input type="text" value="@$t[$i]->{$key}" name="$key"></td></tr>)
+                  if (   $key ne 'subtree'
+                      && $key ne 'rid'
+                      && $key ne 'action'
+                      && $key ne 'dump'
+                      && $key ne 'class'
+                      && $key ne 'addition');
             }
             foreach my $key2 (sort(keys %{$node})) {
                 unless (defined @$t[$i]->{$key2}) {
-                    $m_sContent .= qq(<tr><td></td><td>$node->{$key2}</td></tr><tr><td>$key2 :</td><td><input type="text" value="" name="$key2"/><br/></td></tr>);
+                    $m_sContent .=
+                      qq(<tr><td></td><td>$node->{$key2}</td></tr><tr><td>$key2 :</td><td><input type="text" value="" name="$key2"/><br/></td></tr>);
                 }
             }
-            $m_sContent .= qq(<tr><td><input type="hidden" name="action" value="saveTreeviewEntry"/><input type="hidden" name="rid" value="@$t[$i]->{id}"/></td><td><input type="submit" value="save"/></td></tr></table></form>);
+            $m_sContent .=
+              qq(<tr><td><input type="hidden" name="action" value="saveTreeviewEntry"/><input type="hidden" name="rid" value="@$t[$i]->{id}"/></td><td><input type="submit" value="save"/></td></tr></table></form>);
             saveTree($dump, \@tree);
             return;
         } elsif (defined @{@$t[$i]->{subtree}}) {
@@ -711,11 +735,10 @@ sub editEntry
     }
 }
 
-sub sortUp
-{
+sub sortUp {
     my $t    = shift;
     my $find = shift;
-    for (my $i = 0; $i <= @$t; $i++) {
+    for (my $i = 0 ; $i <= @$t ; $i++) {
         if (defined @$t[$i]) {
             if (@$t[$i]->{rid} == $find) {
                 $i++ if ($down);
@@ -731,11 +754,10 @@ sub sortUp
     }
 }
 
-sub deleteEntry
-{
+sub deleteEntry {
     my $t    = shift;
     my $find = shift;
-    for (my $i = 0; $i < @$t; $i++) {
+    for (my $i = 0 ; $i < @$t ; $i++) {
         if (@$t[$i]->{rid} == $find) {
             splice @$t, $i, 1;
             saveTree($dump, \@tree);
@@ -745,10 +767,9 @@ sub deleteEntry
     }
 }
 
-sub updateTree
-{
+sub updateTree {
     my $t = shift;
-    for (my $i = 0; $i < @$t; $i++) {
+    for (my $i = 0 ; $i < @$t ; $i++) {
         if (defined @$t[$i]) {
             @$t[$i]->{onmouseup}   = "confirmMove()";
             @$t[$i]->{id}          = @$t[$i]->{id};
@@ -757,7 +778,8 @@ sub updateTree
             @$t[$i]->{onmousemove} = "enableDropZone('" . @$t[$i]->{id} . "')";
             @$t[$i]->{onmouseout}  = "disableDropZone('" . @$t[$i]->{id} . "')";
 
-            @$t[$i]->{addition} = qq(<table border="0" cellpadding="0" cellspacing="0" align="right" summary="layout"><tr>
+            @$t[$i]->{addition} =
+              qq(<table border="0" cellpadding="0" cellspacing="0" align="right" summary="layout"><tr>
 <td><a class="treeviewLink$size" target="_blank" title="@$t[$i]->{text}" href="@$t[$i]->{href}"><img src="/style/$m_sStyle/$size/mimetypes/www.png" border="0" alt=""/></a></td>
 <td ><a class="treeviewLink$size" href="$ENV{SCRIPT_NAME}?action=editTreeviewEntry&amp;rid=@$t[$i]->{id}"><img src="/style/$m_sStyle/$size/mimetypes/edit.png" border="0" alt="edit"/></a></td><td><a class="treeviewLink$size" href="$ENV{SCRIPT_NAME}?action=deleteTreeviewEntry&amp;rid=@$t[$i]->{id}"><img src="/style/$m_sStyle/$size/mimetypes/editdelete.png" border="0" alt="delete"/></a></td><td><a class="treeviewLink$size" href="$ENV{SCRIPT_NAME}?action=upEntry&amp;rid=@$t[$i]->{id}#@$t[$i]->{id}"><img src="/style/$m_sStyle/$size/mimetypes/up.png" border="0" alt="up"/></a></td><td><a class="treeviewLink$size" href="$ENV{SCRIPT_NAME}?action=downEntry&amp;rid=@$t[$i]->{id}#@$t[$i]->{id}"><img src="/style/$m_sStyle/$size/mimetypes/down.png" border="0" alt="down"/></a></td><td><a class="treeviewLink$size" href="$ENV{SCRIPT_NAME}?action=newEntry&amp;rid=@$t[$i]->{id}"><img src="/style/$m_sStyle/$size/mimetypes/filenew.png" border="0" alt="new"/></a></td></tr></table>);
             @$t[$i]->{href} = '';
@@ -766,16 +788,14 @@ sub updateTree
     }
 }
 
-sub rid
-{
+sub rid {
     no warnings;
     $m_nRid = 0;
     &getRid(\@tree);
 
-    sub getRid
-    {
+    sub getRid {
         my $t = shift;
-        for (my $i = 0; $i < @$t; $i++) {
+        for (my $i = 0 ; $i < @$t ; $i++) {
             $m_nRid++;
             next unless ref @$t[$i] eq "HASH";
             @$t[$i]->{rid} = $m_nRid;
@@ -785,8 +805,7 @@ sub rid
     }
 }
 
-sub load
-{
+sub load {
     if (-e $dump) {
         loadTree($dump);
         *tree = \@{$HTML::Menu::TreeView::TreeView[0]};
